/*******************
VARIABLES
*******************/
var lastModified = "2017-11-21";
var lastUploaded = "2017-11-21";

var templateVersion = "2.0.23";

var adId, rnd, uid;
var expansionDiv;
var closeButton;
var userActionButton;
var clickthroughButton;
var expandType;
var duration;
var easing;
var panelName;
var bannerWidth;
var bannerHeight;
var sdkData;
var isMRAID;
var useCustomClose;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
		if (window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
			initializeCreative();
			return;
		}
	}
	catch (e) {}

	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function() {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function() {
		eventManager.apply(this, arguments);
	}, this);

	EB.Comm = EB.Comm || new EBG.Comm();
	EB.Comm.setName("expandUser");

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);

	window.registerInteraction = function() {}; //overwrite rI function because it will never actually be called
	initializeGlobalVariables();
	initializeCloseButton();
	addEventListeners();

	easing = getCustomVar("mdEasingType");
	panelName = getCustomVar("mdUserPanelName");
	expandType = getCustomVar("mdUserPanelType");
	duration = expandType.match(/pushdown/i) !== null ? getCustomVar("mdAnimationDuration") * 1000 : 0;

	if (isMRAID || (getCustomVar("mdUserPanelType").match(/fullscreen/i) !== null && getCustomVar("mdLockScrollingWhenExpanded"))) {
		preventPageScrolling();
	}
}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	expansionDiv = document.getElementById("expansion");
	closeButton = document.getElementById("closeButton");
	userActionButton = document.getElementById("userActionButton");
	clickthroughButton = document.getElementById("clickthroughButton");

	if (!isMRAID) {
		sdkData = EB.getSDKData();
		isMRAID = sdkData !== null && sdkData.SDKType === "MRAID";
	}
}

function initializeCloseButton() {
	useCustomClose = !isMRAID || (isMRAID && !getCustomVar("mdEnableSDKDefaultCloseButton"));
	if (useCustomClose) {
		EB.API.setStyle(closeButton, {
			display: "block"
		});
	}
}

function addEventListeners() {
	closeButton.addEventListener("click", handleCloseButtonClick);
	userActionButton.addEventListener("click", handleUserActionButtonClick);
	clickthroughButton.addEventListener("click", handleClickthroughButtonClick);

	if (isMRAID) {
		sendMessage("checkMRAIDState", {
			panelName: panelName
		});
	}
}

/*******************
EVENT HANDLERS
*******************/
function handleCloseButtonClick() {
	if (EB.Comm.isConnected("banner")) {
		EB.Comm.banner.showMessage("expand panel collapsed");
	}

	if (isMRAID) {
		EB.collapse({
			panelName: panelName
		});
		return;
	}

	if (EB.API.os.android || expandType.match(/fullscreen/i) !== null) {
		bannerHeight = 0;
	}

	EB.collapse({
		animate: {
			clip: "rect(" + bannerHeight + "px," + EB.API.Adaptor.getViewPortMetrics().width + "px, 0px, 0px)",
			duration: duration,
			easing: easing,
			alignToElement: false,
			customData: {
				action: "collapse_" + expandType
			}
		},
		panelName: panelName,
	});
}

function handleUserActionButtonClick() {
	EB.userActionCounter("CustomInteraction");
}

function handleClickthroughButtonClick() {
	EB.clickthrough();
}

/*******************
UTILITIES
*******************/
function showMessage(msg) {
	// listen to comm module call back 
}

function panelListener(event) {
	if (event.action === "AnimationStart" && !EB.API.Adaptor.getAdData("isSafeFrame")) {
		EB.API.setStyle(closeButton, {
			display: "none"
		});
	}
	if (event.action === "AnimationComplete" && useCustomClose) {
		EB.API.setStyle(closeButton, {
			display: "block"
		});
	}
}

function preventPageScrolling() {
	document.addEventListener("touchmove", stopScrolling);
}

function allowPageScrolling() {
	document.removeEventListener("touchmove", stopScrolling);
}

function stopScrolling(event) {
	event.preventDefault();
}

// EBCMD function
function collapse() {
	handleCloseButtonClick();
}

function getCustomVar(cv) {
	cv = EB.API.getCustomVar(cv);
	if (typeof(cv) != "undefined") {
		return cv;
	}
	else {
		return "noVarFound";
	}
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if (!data.type) {
		data.type = type;
	}
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId]) {
		delete listenerQueue[listenerId];
	}
}

function eventManager(event) {
	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);
	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}

	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			isMRAID = msg.data.mraid;
			bannerWidth = msg.data.bannerWidth;
			bannerHeight = msg.data.bannerHeight;
			addCustomScriptEventListener("currentExpandData", function(event) {
				bannerWidth = event.bannerWidth;
				bannerHeight = event.bannerHeight;
			}, false);
			addCustomScriptEventListener("panelBehaviour", panelListener, false);
			break;
		case "animationComplete":
			panelListener({
				action: msg.data.action,
				expanding: msg.data.expanding
			});
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for (var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if (!t) continue;
					t.callback(msg.data);
				}
				catch (e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function() {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);